# DCAST-GTK
require 'gtk2'
require 'nkf'
require "allremove-gtk"
#require "first-gtk"
require "first-select-gtk"
require "select-eth-gtk"
require "master-info-gtk"
require "get_master"
require "cluster-info-gtk"
require "mac-info-gtk"
require "get_mac"
require "run-gtk"
require "common"
require "mydialog"
require "fstab-gtk"
require "gettext"

include GetText
bindtextdomain("dcast", localedir="./locale")

# DCAST
require "check"
require "path_class"
